@@ -4,10 +4,13 @@ knitr::opts_chunk$set(
     comment = "#>"
 )
 
+## ----echo = FALSE-------------------------------------------------------------
+options(crayon.enabled = FALSE, cli.num_colors = 0)
+
 ## -----------------------------------------------------------------------------
 library(metasnf)
 
-data_list <- generate_data_list(
+dl <- data_list(
     list(subc_v, "subcortical_volume", "neuroimaging", "continuous"),
     list(income, "household_income", "demographics", "continuous"),
     list(pubertal, "pubertal_status", "demographics", "continuous"),
@@ -17,19 +20,19 @@ data_list <- generate_data_list(
 )
 
 set.seed(42)
-settings_matrix <- generate_settings_matrix(
-    data_list,
-    nrow = 20,
+sc <- snf_config(
+    dl = dl,
+    n_solutions = 20,
     min_k = 20,
     max_k = 50
 )
 
 # Generation of 20 cluster solutions
-solutions_matrix <- batch_snf(data_list, settings_matrix)
+sol_df <- batch_snf(dl, sc)
 
 # Let's just calculate NMIs of the anxiety and depression data types for the
 # first 5 cluster solutions to save time:
-feature_nmis <- batch_nmi(data_list[4:5], solutions_matrix[1:5, ])
+feature_nmis <- calc_nmis(dl[4:5], sol_df[1:5, ])
 
 print(feature_nmis)
 
